@@ -8,10 +8,10 @@
 #ifndef STATISTICSMAINWINDOW_H
 #define STATISTICSMAINWINDOW_H
 
+#include <KXMLGUIClient>
+#include <QWidget>
 #include <memory>
 
-#include <KXmlGuiWindow>
-
 class ConjugationOptions;
 class StatisticsModel;
 class KEduVocDocument;
@@ -21,7 +21,7 @@ namespace Ui
 class StatisticsMainWindow;
 }
 
-class StatisticsMainWindow : public KXmlGuiWindow
+class StatisticsMainWindow : public QWidget, public KXMLGUIClient
 {
     Q_OBJECT
 public:
